aboutsummaryrefslogtreecommitdiff
path: root/mod/mod-ci-github-service-data.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2024-05-28 11:32:51 +0200
committerFrancois Kritzinger <francois@codesynthesis.com>2024-06-05 09:12:46 +0200
commit16f840d9ff5551b4b9577084f1587c524b05d2b0 (patch)
tree95241c3e6e4d8a96a5553db63063a00c8dee179d /mod/mod-ci-github-service-data.hxx
parent0d5dc827745a0d80cf957863629f17282f82bb48 (diff)
Review
Diffstat (limited to 'mod/mod-ci-github-service-data.hxx')
-rw-r--r--mod/mod-ci-github-service-data.hxx32
1 files changed, 28 insertions, 4 deletions
diff --git a/mod/mod-ci-github-service-data.hxx b/mod/mod-ci-github-service-data.hxx
index 252f992..4a433c5 100644
--- a/mod/mod-ci-github-service-data.hxx
+++ b/mod/mod-ci-github-service-data.hxx
@@ -61,17 +61,30 @@ namespace brep
// The following two are only used for pull requests.
//
+ // @@ TODO/LATER: maybe put them in a struct?
+ //
optional<string> repository_clone_url;
optional<uint32_t> pr_number;
+ // The GitHub ID of the synthetic PR merge check run or absent if it
+ // hasn't been created yet.
+ //
+ optional<string> merge_node_id;
+
// The commit ID the check suite or pull request (and its check runs) are
// associated with. In the case of a pull request this will be
// `pull_request.head.sha`.
//
string head_sha;
vector<check_run> check_runs;
+ // The GitHub ID of the synthetic conclusion check run or absent if it
+ // hasn't been created yet. See also merge_node_id above.
+ //
+ optional<string> conclusion_node_id;
+
// Return the check run with the specified build ID or nullptr if not
// found.
//
@@ -85,14 +98,25 @@ namespace brep
explicit
service_data (const string& json);
+ // The check_suite constructor.
+ //
+ service_data (bool warning_success,
+ string iat_token,
+ timestamp iat_expires_at,
+ uint64_t installation_id,
+ string repository_node_id,
+ string head_sha);
+
+ // The pull_request constructor.
+ //
service_data (bool warning_success,
string iat_token,
timestamp iat_expires_at,
uint64_t installation_id,
string repository_node_id,
string head_sha,
- optional<string> repository_clone_url = nullopt,
- optional<uint32_t> pr_number = nullopt);
+ string repository_clone_url,
+ uint32_t pr_number);
service_data () = default;
@@ -61,17 +61,30 @@ namespace brep
// The commit ID the check suite or pull request (and its check runs) are
- // associated with. In the case of a pull request this will be
- // `pull_request.head.sha`.
+ // associated with. Note that in the case of a pull request this will be
+ // the head commit (`pull_request.head.sha`) as opposed to the merge
+ // commit.
//
string head_sha;